logutils

package
v0.0.0-...-1fe37ed Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 20, 2017 License: MIT, MPL-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package logutils augments the standard log package with levels.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LevelFilter

type LevelFilter struct {
	// Levels is the list of log levels, in increasing order of
	// severity. Example might be: {"DEBUG", "WARN", "ERROR"}.
	Levels []LogLevel

	// MinLevel is the minimum level allowed through
	MinLevel LogLevel

	// The underlying io.Writer where log messages that pass the filter
	// will be set.
	Writer io.Writer
	// contains filtered or unexported fields
}

LevelFilter is an io.Writer that can be used with a logger that will filter out log messages that aren't at least a certain level.

Once the filter is in use somewhere, it is not safe to modify the structure.

func (*LevelFilter) Check

func (f *LevelFilter) Check(line []byte) bool

Check will check a given line if it would be included in the level filter.

func (*LevelFilter) SetMinLevel

func (f *LevelFilter) SetMinLevel(min LogLevel)

SetMinLevel is used to update the minimum log level

func (*LevelFilter) Write

func (f *LevelFilter) Write(p []byte) (n int, err error)

type LogLevel

type LogLevel string

Source Files

  • level.go

Jump to